@@ -18,7 +18,7 @@ Readonly::Scalar my $LAST_INDEX => -1;
 Readonly::Scalar my $SPACE => q{ };
 
 # Version.
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 # Resets internal variables.
 sub reset {
@@ -269,9 +269,13 @@ sub _put_data {
 sub _put_end_of_tag {
 	my ($self, $tag) = @_;
 	my $printed = shift @{$self->{'printed_tags'}};
-	if ($self->{'xml'} && $printed ne $tag) {
-		err "Ending bad tag: '$tag' in block of ".
-			"tag '$printed'.";
+	if ($self->{'xml'}) {
+		if (! defined $printed) {
+			err "Ending bad tag: '$tag' doesn't begin.";
+		} elsif ($printed ne $tag) {
+			err "Ending bad tag: '$tag' in block of ".
+				"tag '$printed'.";
+		}
 	}
 
 	# Tag can be simple.
@@ -538,6 +542,7 @@ __END__
  put():
          Bad tag type 'a'.
          Bad CDATA data.
+         Ending bad tag: '%s' doesn't begin.
          Ending bad tag: '%s' in block of tag '%s'.
          In XML mode must be a attribute '%s' value.
          In XML must be lowercase tag name.
@@ -638,11 +643,11 @@ L<http://skim.cz/>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2005-2015 Michal Špaček
+ © 2005-2016 Michal Špaček
  BSD 2-Clause License
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
